@@ -1,5 +1,9 @@
 #!/usr/bin/env python
 
+"""
+functionality related to templates
+"""
+
 import os
 import sys
 from optparse import OptionParser
@@ -17,18 +21,28 @@ def template_dirs():
         if os.path.isdir(template_dir):
             template_dirs.add(template_dir)
     return template_dirs
-        
+
+
 def templates():
     templates = []
     for directory in template_dirs():
-        templates.extend([os.path.join(directory, filename) 
+        templates.extend([os.path.join(directory, filename)
                           for filename in os.listdir(directory)
                           if filename.endswith('.html')])
     return templates
 
+
 def main(args=sys.argv[1:]):
+
+    # comman line option parser
+    description = 'list available templates'
+    parser = OptionParser(description=description)
+    options, args = parser.parse_args(args)
+
+    # list templates
     for template in templates():
         print template
 
+
 if __name__ == '__main__':
     main()
