@@ -30,13 +30,15 @@ from webob import Request, Response, exc
 
 transformers = transformers()
 
+string = (str, unicode)
+
 class Decoupage(object):
 
     ### class level variables
-    defaults = { 'auto_reload': 'False',
+    defaults = { 'auto_reload': False,
                  'configuration': None,
                  'directory': None, # directory to serve
-                 'cascade': 'True', # whether to cascade configuration
+                 'cascade': True, # whether to cascade configuration
                  'template': 'index.html', # XXX see below
                  'template_directories': '', # list of directories to look for templates
                  'charset': 'utf-8', # content encoding for index.html files; -> `Content-Type: text/html; charset=ISO-8859-1`
@@ -45,13 +47,21 @@ class Decoupage(object):
     def __init__(self, **kw):
 
         # set defaults from app configuration
-        for key in self.defaults:
-            setattr(self, key, kw.get(key, self.defaults[key]))
+        for key, default_value in self.defaults.items():
+
+            value = kw.get(key, default_value)
+
+            # handle non-string bools
+            if isinstance(default_value, bool) and isinstance(value, string):
+                value = {'true': True,
+                         'false': False}[value.lower()]
+                # TODO: error handling for bad strings
+
+            setattr(self, key, value)
+
 
         # configure defaults
         assert self.directory, "Decoupage: directory not specified"
-        self.auto_reload = self.auto_reload.lower() == 'true'
-        self.cascade = self.cascade.lower() == 'true'
         self.directory = self.directory.rstrip(os.path.sep)
         assert os.path.isdir(self.directory), "'%s' is not a directory" % self.directory
         self.template_directories = self.template_directories.split() # no spaces in directory names, for now
@@ -179,20 +189,8 @@ class Decoupage(object):
         data['scripts'] = ()
 
         # apply formatters
-        # XXX this should be cached if not self.auto_reload
-        if '/formatters' in conf:
-            # ordered list of formatters to be applied first
-            formatters = [ i for i in conf['/formatters'].split()
-                           if i in self.formatters ]
-        else:
-            formatters = []
-        for key in conf:
-            if key.startswith('/'):
-                key = key[1:]
-                if key in self.formatters and key not in formatters:
-                    formatters.append(key)
-        for name in formatters:
-            formatter = self.formatters[name](conf.get('/%s' % name, ''))
+        formatters = self.get_formatters(path)
+        for formatter in formatters:
             formatter(request, data)
 
         # return an alternate format if specified
@@ -342,11 +340,23 @@ class Decoupage(object):
 
         return conf
 
-    def fmtrs(self, path):
-        formatters = []
-        for key, value in self.conf(path).items():
+    def get_formatters(self, path):
+        """return formatters for a path"""
+        retval = []
+        conf = self.conf(path)
+        # apply formatters
+        # XXX this should be cached if not self.auto_reload
+        if '/formatters' in conf:
+            # ordered list of formatters to be applied first
+            formatters = [ i for i in conf['/formatters'].split()
+                           if i in self.formatters ]
+        else:
+            formatters = []
+        for key in conf:
             if key.startswith('/'):
                 key = key[1:]
-                if key in self.formatters:
-                    formatter = self.formatters[key](value)
+                if key in self.formatters and key not in formatters:
+                    formatters.append(key)
+        for name in formatters:
+            retval.append(self.formatters[name](conf.get('/%s' % name, '')))
 
